@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Calculate date-time operations
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use strict;
 use warnings;
@@ -121,7 +121,7 @@ Bot::BasicBot::Pluggable::Module::DateTimeCalc - Calculate date-time operations
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
@@ -134,6 +134,8 @@ version 0.0201
 A C<Bot::BasicBot::Pluggable::Module::DateTimeCalc> calculates date-time
 operations.
 
+This bot is coded to only respond when directly addressed, btw.
+
 Since this module uses L<Date::Manip>, many different date-time formats are
 supported.
 
@@ -182,7 +184,7 @@ stamps.
 
 =head2 {add,sub}_{years,months,days,hours,minutes,seconds}
 
-  > add_days '1/2/2032'
+  > TimeBot: add_days '1/2/2032'
 
 Add or subtract the the given span from the given date-time stamp.
 
